@@ -27,6 +27,7 @@
 #include "kodi/Network.h"
 #include "JWT.h"
 
+#include <mutex>
 #include <map>
 #include <vector>
 
@@ -37,7 +38,8 @@ static const int WAIPU_LOGIN_FAILED_LOCK_LIMIT = 3;
 enum WAIPU_PROVIDER
 {
   WAIPU_PROVIDER_WAIPU = 0,
-  WAIPU_PROVIDER_O2
+  WAIPU_PROVIDER_O2 = 1,
+  WAIPU_PROVIDER_WAIPU_DEVICE = 2
 };
 
 enum class WAIPU_LOGIN_STATUS
@@ -68,7 +70,6 @@ public:
   PVR_ERROR GetCapabilities(kodi::addon::PVRCapabilities& capabilities) override;
   PVR_ERROR GetBackendName(std::string& name) override;
   PVR_ERROR GetBackendVersion(std::string& version) override;
-  PVR_ERROR GetConnectionString(std::string& connection) override;
 
   PVR_ERROR GetChannelsAmount(int& amount) override;
   PVR_ERROR GetChannels(bool radio, kodi::addon::PVRChannelsResultSet& results) override;
@@ -123,6 +124,7 @@ private:
     std::vector<WaipuChannel> channels;
   };
 
+  static std::mutex mutex;
   std::string m_username;
   std::string m_password;
   std::string m_userhandle = "";
@@ -151,16 +153,18 @@ private:
   HLSAllowlist m_hls_allowlist;
   Categories m_categories;
 
-  void ReadSettings(void);
-  bool ParseAccessToken(void);
+  void ReadSettings();
+  bool ParseAccessToken();
 
   void AddTimerType(std::vector<kodi::addon::PVRTimerType>& types, int idx, int attributes);
 
-  std::string GetChannelStreamUrl(int uniqueId, const std::string& protocol, const std::string& startTime);
+  std::string GetChannelStreamURL(int uniqueId, const std::string& protocol, const std::string& startTime);
   std::string GetRecordingURL(const kodi::addon::PVRRecording& recording,
                               const std::string& protocol);
   std::string GetEPGTagURL(const kodi::addon::PVREPGTag& tag, const std::string& protocol);
-  std::string GetLicense(void);
+  std::string GetLicense();
+  const std::map<std::string,std::string> GetOAuthDeviceCode(const std::string& tenant);
+  const std::map<std::string,std::string> CheckOAuthState(const std::string& device_code);
   void SetStreamProperties(std::vector<kodi::addon::PVRStreamProperty>& properties,
                            const std::string& url,
                            bool realtime, bool playTimeshiftBuffer, const std::string& protocol);
@@ -173,7 +177,8 @@ private:
       Curl& curl, const std::string& action, const std::string& url, const std::string& postData, int& statusCode);
   bool ApiLogin();
   bool WaipuLogin();
-  bool O2Login();
-  bool LoadChannelData(void);
-  bool RefreshDeviceCapabiltiesToken(void);
+  bool DeviceLogin(const std::string& tenant);
+  bool OAuthRequest(const std::string& postData);
+  bool LoadChannelData();
+  bool RefreshDeviceCapabiltiesToken();
 };
